@@ -3,7 +3,10 @@ from .schema import PlayerMove, Player
 
 
 class LogWriter:
-    def __init__(self, path: str, player_moves: List[PlayerMove], winner: Optional[Player] = None, error_message: Optional[str] = None) -> None:
+    def __init__(
+        self, path: str, player_moves: List[PlayerMove],
+        winner: Optional[Player] = None, error_message: Optional[str] = None
+    ) -> None:
         self.path = path
         self.player_moves = player_moves
         self.winner = winner
@@ -13,7 +16,7 @@ class LogWriter:
         formatted_moves: List[str] = []
         for player_move in self.player_moves:
             move = player_move.move
-            formatted_move = f'M, {player_move.player}, {move.src.x} {move.src.y} {move.dst.x} {move.dst.y}'
+            formatted_move = f'M, {player_move.player}, {move.src.row} {move.src.col} {move.dst.row} {move.dst.col}\n'
             formatted_moves.append(formatted_move)
         return formatted_moves
 
@@ -22,6 +25,6 @@ class LogWriter:
         with open(self.path, "w+") as log_file:
             log_file.writelines(formatted_moves)
             if self.winner is not None:
-                log_file.write(f"W, Player {self.winner} wins")
+                log_file.write(f"W, Player {self.winner} wins\n")
             elif self.error_message is not None:
-                log_file.write(f"E, {self.error_message}")
+                log_file.write(f"E, {self.error_message}\n")
