@@ -5,7 +5,7 @@ import typer
 
 from .simulator import Simulator
 from .custom_exceptions import InvalidMovesException,  TimeoutException, MovesExceededException
-from .schema import PlayerMove, Player, GameResult
+from .schema import PlayerMove, Player, GameResult, Position, Move, Piece
 from .log_writer import LogWriter
 from .logger_utils import get_logger
 
@@ -14,16 +14,21 @@ app = typer.Typer()
 
 @app.command()
 def play_game(
-    player1_url: str = typer.Argument(...,
-                                      help="The url of the bot for player 1"),
-    player0_url: str = typer.Argument(...,
-                                      help="The url of the bot for player 0"),
-    log_file: str = typer.Argument(default="./logs/local",
-                                   help="The path to which log file should be written"),
-    verbose: bool = typer.Argument(
-        default=False, help="Whether to print out board states and moves when running simulator"),
-    simulation_logs_level: int = typer.Argument(default=logging.WARNING,
-                                                 help="Logs level for simulator logs", show_default=True)
+    player1: str = typer.Option(
+        ..., help="The url of the bot for player 1",
+    ),
+    player0: str = typer.Option(
+        ..., help="The url of the bot for player 0"
+    ),
+    log_file: str = typer.Option(
+        default="./logs/game.log", help="The path to which log file should be written"
+    ),
+    visualize: bool = typer.Option(
+        default=False, help="Whether to print out board states and moves when running simulator"
+    ),
+    log_level: int = typer.Option(
+        default=logging.WARNING, help="Logs level for simulator logs", show_default=True
+    )
 ) -> GameResult:
     """
     Judge for the TU game. Enter the endpoints for bots
@@ -31,13 +36,13 @@ def play_game(
     """
     bot_data = [{}, {}]
     player_moves: List[PlayerMove] = []
-    logger = get_logger(__name__, level=simulation_logs_level)
+    logger = get_logger(__name__, level=log_level)
     game_simulator = Simulator(
-        verbose=verbose, logging_level=simulation_logs_level)
+        verbose=visualize, logging_level=log_level)
     try:
         logger.info(
-            f"Starting simulation of game for bot1: {player1_url}, bot2: {player0_url}")
-        winner = game_simulator.run([player1_url, player0_url],
+            f"Starting simulation of game for bot1: {player1}, bot2: {player0}")
+        winner = game_simulator.run([player1, player0],
                                     bot_data=bot_data, player_moves=player_moves)
         logger.info(
             "Game successfully completed. Writing game moves to log file")
@@ -70,6 +75,7 @@ def play_game(
     except Exception as ex:  # just in case
         logger.error(
             "Internal error while simulating game. Invalidating Game result")
+        logger.error(ex)
         log_writer = LogWriter(
             path=log_file, player_moves=player_moves, error_message=str(ex))
         log_writer.write()
