@@ -6,14 +6,13 @@ import logging
 import requests
 from requests import Timeout
 from colorama import Fore, Style
+from pydantic import ValidationError
 
 from .schema import Piece, Move, Player, InvalidMovesMessage, BotResponse, PlayerMove
 from .custom_exceptions import InvalidMovesException, TimeoutException, MovesExceededException
 from .constants import MAX_MOVES_ALLOWED
 from .logger_utils import get_logger
 
-logging.basicConfig()
-
 
 class Simulator:
     def __init__(self, move_timeout: int = 4, verbose: bool = True, logging_level: int = logging.WARNING) -> None:
@@ -22,8 +21,7 @@ class Simulator:
         self.RED_PIECES = [Piece.RED_BOMBER, Piece.RED_STINGER]
         self.BLUE_PIECES = [Piece.BLUE_BOMBER, Piece.BLUE_STINGER]
         self.move_timeout = move_timeout
-        self.logger = get_logger(__name__)
-        self.logger.setLevel(level=logging_level)
+        self.logger = get_logger(__name__, level=logging_level)
         self.verbose = verbose
 
     def print_board(self):
@@ -33,15 +31,15 @@ class Simulator:
         if self.verbose:
             print(Fore.BLACK + Style.BRIGHT + "  0 1 2 3 4")
             for index, row in enumerate(self.board):
-                print(Fore.BLACK + Style.BRIGHT + str(index) + " ")
+                print(Fore.BLACK + Style.BRIGHT + str(index) + " ", end="")
                 for cell in row:
                     if cell in self.RED_PIECES:
-                        print(Fore.RED + cell + " ")
+                        print(Fore.RED + cell + " ", end="")
                     elif cell in self.BLUE_PIECES:
-                        print(Fore.BLUE + cell + " ")
+                        print(Fore.BLUE + cell + " ", end="")
                     else:
-                        print(Fore.WHITE + cell + " ")
-                print()
+                        print(Fore.WHITE + cell + " ", end="")
+                print(Fore.RESET + Style.RESET_ALL)
 
     @staticmethod
     def validate_direction(move: Move, player: Player):
@@ -49,14 +47,14 @@ class Simulator:
         Check if player is moving in correct vertical direction, blue should move down the board, red should move up
         """
         sign = 2*player - 1
-        absolute_direction = move.dst.y - move.src.y
+        absolute_direction = move.dst.row - move.src.row
         if absolute_direction*sign < 0:
             raise InvalidMovesException(
                 reason=InvalidMovesMessage.INVALID_DIRECTION, player=player)
 
     def validate_endpoints(self, move: Move, player: Player) -> None:
         """
-        Check if the source and destination endpoints are valid. 
+        Check if the source and destination endpoints are valid.
         Source should hold a piece of the player and destination should be an empty space
         Raise an exception if this is not followed, return None otherwise
 
@@ -70,46 +68,45 @@ class Simulator:
         InvalidMovesException
         InvalidMovesException
         """
-        if self.board[move.dst.x][move.dst.y] != Piece.EMPTY_SPACE:
-            raise InvalidMovesException(
-                reason=InvalidMovesMessage.INVALID_DESTINATION, player=player)
-        if (
-            player == player.BLUE and self.board[move.src.x][move.src.y] not in self.BLUE_PIECES
-        ) or (
-            player == player.RED and self.board[move.src.x][move.src.y] not in self.RED_PIECES
+        if self.board[move.dst.row][move.dst.col] != Piece.EMPTY_SPACE:
+            raise InvalidMovesException(reason=InvalidMovesMessage.INVALID_DESTINATION, player=player)
+        if (player == player.BLUE and self.board[move.src.row][move.src.col] not in self.BLUE_PIECES) or (
+            player == player.RED and self.board[move.src.row][move.src.col] not in self.RED_PIECES
         ):
-            raise InvalidMovesException(
-                reason=InvalidMovesMessage.INVALID_SOURCE, player=player)
+            raise InvalidMovesException(reason=InvalidMovesMessage.INVALID_SOURCE, player=player)
         return None
 
     def validate_elimination_move(self, move: Move, player: Player) -> None:
-        if move.src.x == move.dst.y == 0 or move.src.x == move.src.y == 4:
+
+        if move.src.row == move.dst.row == 0 or move.src.row == move.dst.row == 4:
             raise InvalidMovesException(
                 reason=InvalidMovesMessage.HOME_ROW_ELIMINATION_FORBIDDEN, player=player)
-        eliminated_x_coord = int((move.src.x + move.dst.x) / 2)
-        eliminated_y_coord = int((move.src.y + move.dst.y) / 2)
-        eliminated_piece = self.board[eliminated_x_coord][eliminated_y_coord]
+        eliminated_row = int((move.src.row + move.dst.row) / 2)
+        eliminated_col = int((move.src.col + move.dst.col) / 2)
+        eliminated_piece = self.board[eliminated_row][eliminated_col]
 
         if (
-            player.RED and eliminated_piece in self.BLUE_PIECES
+            player == Player.RED and eliminated_piece in self.BLUE_PIECES
         ) or (
-            player.BLUE and eliminated_piece in self.RED_PIECES
+            player == Player.BLUE and eliminated_piece in self.RED_PIECES
         ):
             return None
         else:
+            print(f"{self.BLUE_PIECES}, {self.RED_PIECES}")
+            print(f"player {player}, elim_coords {eliminated_row, eliminated_col}, eliminated_piece: {eliminated_piece}")
             raise InvalidMovesException(
                 reason=InvalidMovesMessage.INVALID_ELIMINATION_TARGET, player=player)
 
     def validate_stinger_move(self, move: Move, player: Player):
-        if abs(move.src.x - move.dst.x) == abs(move.src.y - move.dst.y) == 1:
+        if abs(move.src.row - move.dst.row) == abs(move.src.col - move.dst.col) == 1:
             # simply diagonal move (direction in y axis has already been validated)
             return None
         elif (
             # horizontal elimination
-            abs(move.src.x - move.dst.x) == 2 and move.src.y == move.dst.y
+            abs(move.src.row - move.dst.row) == 2 and move.src.col == move.dst.col
         ) or (
             # vertical elimination
-            abs(move.src.y - move.dst.y) == 2 and move.src.x == move.dst.y
+            abs(move.src.col - move.dst.col) == 2 and move.src.row == move.dst.row
         ):
             self.validate_elimination_move(move, player)
         else:
@@ -118,14 +115,14 @@ class Simulator:
                 reason=InvalidMovesMessage.INVALID_STINGER_MOVE, player=player)
 
     def validate_bomber_move(self, move: Move, player: Player):
-        if abs(move.src.y - move.dst.y) <= 1 and abs(move.src.x - move.dst.x) <= 1 and move.src != move.dst:
+        if abs(move.src.col - move.dst.col) <= 1 and abs(move.src.row - move.dst.row) <= 1 and move.src != move.dst:
             return  # single move in any direction
         elif (
             # horizontal elimination
-            abs(move.src.x - move.dst.x) == 2 and move.src.y == move.dst.y
+            abs(move.src.row - move.dst.row) == 2 and move.src.col == move.dst.col
         ) or (
             # vertical elimination
-            abs(move.src.y - move.dst.y) == 2 and move.src.x == move.dst.y
+            abs(move.src.col - move.dst.col) == 2 and move.src.row == move.dst.row
         ):
             self.validate_elimination_move(move, player)
         else:
@@ -141,10 +138,18 @@ class Simulator:
         move : Move
         player : Player
         """
-        self.logger.info("Validating ")
+        self.logger.info(f"Validating Player {player} Move")
+        if self.verbose:
+            if player == Player.BLUE:
+                color = Fore.BLUE
+            else:
+                color = Fore.RED
+            print(color + Style.BRIGHT + f"Player {player} move")
+            print(color + Style.BRIGHT + str(move))
+            print(Fore.RESET + Style.RESET_ALL)
         self.validate_direction(move, player)
         self.validate_endpoints(move, player)
-        piece = self.board[move.src.x][move.src.y]
+        piece = self.board[move.src.row][move.src.col]
         if piece in [Piece.BLUE_STINGER, Piece.RED_STINGER]:
             self.validate_stinger_move(move, player)
         else:
@@ -159,11 +164,11 @@ class Simulator:
         move : Move
         player : Player
         """
-        self.board[move.dst.x][move.dst.y] = self.board[move.src.x][move.src.y]
-        self.board[move.src.x][move.src.y] = Piece.EMPTY_SPACE
-        if abs(move.src.x - move.dst.x) == 2 or abs(move.src.y - move.dst.y) == 2:
-            eliminated_x_coord = int((move.src.x + move.dst.x) / 2)
-            eliminated_y_coord = int((move.src.y + move.dst.y) / 2)
+        self.board[move.dst.row][move.dst.col] = self.board[move.src.row][move.src.col]
+        self.board[move.src.row][move.src.col] = Piece.EMPTY_SPACE
+        if abs(move.src.row - move.dst.row) == 2 or abs(move.src.col - move.dst.col) == 2:
+            eliminated_x_coord = int((move.src.row + move.dst.row) / 2)
+            eliminated_y_coord = int((move.src.col + move.dst.col) / 2)
             self.board[eliminated_x_coord][eliminated_y_coord] = Piece.EMPTY_SPACE
 
     def check_if_game_over(self) -> Tuple[bool, Player | None]:
@@ -177,7 +182,7 @@ class Simulator:
 
     def run(self, bot_urls: List[str], bot_data: List[Any], player_moves: List[PlayerMove]):
         player = Player.BLUE
-        print("STARTING GAME")
+        self.logger.info("STARTING GAME")
         self.print_board()
         while len(player_moves) < MAX_MOVES_ALLOWED:
             bot_input = {
@@ -185,21 +190,19 @@ class Simulator:
                 "data": bot_data[player],
                 "player": player
             }
-            response = requests.post(
-                bot_urls[player], json=bot_input, timeout=self.move_timeout)
+
+            response = requests.post(bot_urls[player], json=bot_input, timeout=self.move_timeout)
             if response.status_code != 200:
                 self.logger.error(
-                    f"Invalid stauts code {response.status_code} received from player {player}. Expected: {200}")
-                raise InvalidMovesException(
-                    InvalidMovesMessage.INVALID_STATUS_CODE, player=player)
+                    f"Invalid status code {response.status_code} received from player {player}. Expected: {200}")
+                raise InvalidMovesException(InvalidMovesMessage.INVALID_STATUS_CODE, player=player)
+
             try:
-                bot_response = BotResponse.validate(
-                    json.loads(response.content))
+                bot_response = BotResponse.validate(json.loads(response.content))
                 bot_data[player] = bot_response.data
+                player_moves.append(PlayerMove(move=bot_response.move, player=player))
+
                 self.validate_move(bot_response.move, player=player)
-                if self.verbose:
-                    print(f"Player {player} move")
-                    print(bot_response.move)
                 self.make_move(bot_response.move, player=player)
                 self.print_board()
                 game_over, winner = self.check_if_game_over()
@@ -207,18 +210,20 @@ class Simulator:
                     if self.verbose:
                         print(f"Player {player} wins")
                     return winner
-                player_moves.append(PlayerMove(
-                    move=bot_response.move, player=player))
-                player ^= player  # toggles player but pylance infers type of player as int
-                # functions expect call of type Player Enum. Adding this cast to silence pylance errors
-                player = Player(player)
+                if player == Player.BLUE:
+                    player = Player.RED
+                else:
+                    player = Player.BLUE
             except InvalidMovesException as imex:
-                self.logger.error(
-                    f"Invalid response received from player: {player}. Message: ", imex.message)
-                raise InvalidMovesException(
-                    reason=imex.reason, player=player)  # append player info to exception
+                self.logger.error(f"Invalid response received from player: {player}. Message: ", imex.message)
+                raise InvalidMovesException(reason=imex.reason, player=player)  # append player info to exception
             except Timeout as t:
                 self.logger.error(
                     f"Request to player: {player} times out")
                 raise TimeoutException(player=player)
+            except ValidationError as ve:
+                self.logger.error(
+                    f"Invalid response received from player: {player}. Message: ", str(ve))
+                raise InvalidMovesException(
+                    reason=f"Incorrect schema. Expected schema: {BotResponse.schema()}", player=player)
         raise MovesExceededException()
